now_epoch

Function now_epoch 

pub fn now_epoch() -> f64
Current time as an RFC3339 string (AppSync’s timestamp members serialise as epoch-seconds on the restJson1 wire, but stored objects only need to be self-consistent; epoch floats are used where the model declares a timestamp).